cap log close
if(${logfile}==1) log using "${log}/04_merge_basic_BHP_MODIFIED.log", replace


/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	SIAB Preparation
	
	Merge the basic Establishment History Panel (BHP) data to the SIAB	
	
	
	Author(s): Wolfgang Dauth, Johann Eppelsheimer, Heiko Stüber
	
	Version: 1.0
	Created: 2022-11-24
	
	Note: 
	This do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


********************************************************************************
* Merge basic BHP information to individual data
********************************************************************************
label language de // needed to make sure that labels are merged correct
/* 
By default, only the variables ao_bula and w93_3_gen from the Basic Establishment File are merged to the SIAB. 
To merge further selected variables from the Basic Establishment File to the SIAB, add them into the "keepusing()" option in line 27. 
To merge all variables of the Basic Establishment File to the SIAB, comment out line 35 and uncomment line 36.
*/
merge m:1 betnr jahr using "${orig}/SIAB_7517_v1_bhp_basis_v1.dta", keep(master match) keepusing(ao_kreis w93_3_gen) 
*merge m:1 betnr jahr using "${orig}/SIAB_7519_v1_bhp_basis_v2.dta", keep(master match) 

* Inspect merge
if(${inspect}==1) tab erwstat _merge // not matched individuals are in almost all cases non-workers
drop _merge

sort persnr spell

* Create county ("Bundesland") variable
*--------------------------------------
gen ao_bula=floor(ao_kreis/1000)
label variable ao_bula "Arbeitsort - Bundesland"
label define bulalb 1 "1 Schleswig-Holstein" 2 "2 Hamburg" 3 "3 Lower Saxony" 4 "4 Bremen" ///
	5 "5 North Rhine-Westphalia" 6 "6 Hesse" 7 "7 Rhineland-Palatinate" 8 "8 Baden-Wuerttemberg" ///
	9 "9 Bavaria" 10 "10 Saarland" 11 "11 Berlin" 12 "12 Brandenburg" 13 "13 Mecklenburg-Western Pomerania" ///
	14 "14 Saxony" 15 "15 Saxony-Anhalt" 16 "16 Thuringia"
label value ao_bula bulalb


cap log close
