cap log close
if(${logfile}==1) log using "${log}/05_educ_broad_MODIFIED.log", replace


/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	SIAB Preparation
	
	Create broader education groups based on imputed education ("ausbildung_imp")
	
	Generates the variable educ: Education (university and university of applied science combined), imputed based on Fitzenberger et al. (2006)
	Fitzenberger, B., A. Osikominu, and R. Völter (2006): Imputation Rules to Improve the Education Variable in the IAB Employment Subsample. Schmollers Jahrbuch. Zeitschrift für Wirtschafts- und Sozialwissenschaften 126(3), 405-436.

	
	Author(s): Wolfgang Dauth, Johann Eppelsheimer, Heiko Stüber
	
	Version: 1.0
	Created: 2022-11-24
	
	Note: 
	This do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w
	
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


********************************************************************************
* Generate a more general education variable based on imputed education from the FDZ
********************************************************************************
* Generate broader education classes
gen educ = .
replace educ = 3 if inlist(ausbildung_imp, 5, 6)	// degree from an university (Universität) or university of applied science (Fachhochschule)
replace educ = 2 if inlist(ausbildung_imp, 2, 4)	// vocational training (Ausbildung)
replace educ = 1 if inlist(ausbildung_imp, 1, 3)	// neither vocational training nor degree from university (of applied science)
replace educ = 1 if missing(ausbildung_imp)==1 

* Define and set labels
label language de
label variable educ "Bildung, imputiert auf der Grundlage von Fitzenberger, Osikominu, & Voelter (2006)"
label define lblValEduc 1 "1 keine Berufsausbildung oder missing" 2 "2 Berufsbildung" 3 "3 Universität oder Fachhochschule"
label values educ lblValEduc
label language en
label variable educ "Education, imputed based on Fitzenberger, Osikominu, & Voelter (2006)"
label define lblValEducen 1 "1 no vocational training or missing" 2 "2 vocational training" 3 "3 university or university of applied science"
label values educ lblValEducen

********************************************************************************
* Comparison
********************************************************************************
if(${inspect}==1) tab ausbildung_imp educ, m


cap log close
