cap log close
if(${logfile}==1) log using "${log}/17_clean_up.log", replace


/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	SIAB Preparation
	
	Clean up the data set
	
	
	Author(s): Wolfgang Dauth, Johann Eppelsheimer, Heiko Stüber

	Version: 1.0
	Created: 2022-11-24

	Note: 
	This do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


********************************************************************************
* Sort the data
********************************************************************************
sort persnr jahr		// if yearly panel
*sort persnr nspell		// if spell data


********************************************************************************
* Declare panel structure
********************************************************************************
xtset persnr jahr		// if yearly panel
*xtset persnr nspell	// if spell data


********************************************************************************
* Drop unnecessary variables
********************************************************************************
*drop ...


********************************************************************************
* Rename variables
********************************************************************************
* rename ...
/*
* Rename variables of basic BHP dataset to BHP_***
foreach var of varlist w73_3 w93_5 w93_3 w03_5 w03_3 w08_5 w08_3 w73_3_gen group_w73_3 w93_3_gen group_w93_3 w08_3_gen group_w08_3 grd_jahr grd_dat lzt_jahr lzt_dat az_ges az_vz az_gf te_imp_mw ao_kreis ao_bula {
rename `var' BHP_`var'
}
*/


********************************************************************************
* Order of variables
********************************************************************************
*order persnr jahr ...


********************************************************************************
* Compress the data
********************************************************************************
unab compVars : _all
unab exclude : persnr betnr
local compVars : list varlist - exclude		// excluding identifier variables
compress $compVars


* Rename jahr year (for part-time correction procedure)
*-----------------
rename jahr year


cap log close
