capture log close
log using "${log}/18c_parttime_correction.log", replace


********************************************************************************
* 18c_parttime_correction.do														
* Implements part-time correction procedure following Fitzenberger and			
* Seidlitz (2020).			
*
* Fitzenberger, Bernd, and Arnim Seidlitz. "The 2011 break in the part-time 
* indicator and the evolution of wage inequality in Germany." Journal for 
* Labour Market Research 54.1 (2020): 1-14.
*
* Create full-time equivalence weights:										
* - original part-time spells: 0.5												
* - full-time spells get a weight between 0 and 1 according to the predictions 	
*   from the Probit models implemented below (separately by gender, age groups 	
*   etc.)																		
********************************************************************************

use "${data}/siab_clean.dta", replace 

* Merge with part-time corrected data for East and West Germany
*---------------------------------------------------------------
merge 1:m persnr year using "${data}/siab_clean_east.dta" // add new variables (no update replace here since variables not yet existed!)
drop _merge

merge 1:m persnr year using "${data}/siab_clean_west.dta", update replace // (update replace since variables for East Germany already added)
drop _merge

sort persnr year 

* Adjust weights for remaining employment spells which did not receive a full-time weight
*----------------------------------------------------------------------------------------
/* Primarily spells from East Germany before 1994.*/
gen m=(weight==. & quelle==1)
tab year m if quelle==1, m

replace weight=1 if teilzeit==0 & m==1 
replace weight=0.5 if teilzeit==1 & m==1 
replace days=endepi-begepi+1 if m==1
replace schalt=0 if quelle==1 & schalt==. 
forvalue x=1976(4)2012{
        replace schalt=1 if year==`x' & m==1
}
replace daysfrac=days/365 if schalt==0 & m==1
replace daysfrac=days/366 if schalt==1 & m==1 
replace weight_duration_ft=daysfrac*weight if m==1
drop m
/*
* Adjust weights for unemployment spells
*---------------------------------------
replace weight=1 if quelle!=1 // UI benefit spells will be considered equivalent to full-time spells
replace days=endepi-begepi+1 if quelle!=1 
assert dur_benefits==days if quelle!=1 // check that benefits duration indeed corresponds to days
replace schalt=0 if quelle!=1 
forvalue x=1976(4)2012{
        replace schalt=1 if year==`x' & quelle!=1 
}
replace daysfrac=days/365 if schalt==0 & quelle!=1 
replace daysfrac=days/366 if schalt==1 & quelle!=1 
replace weight_duration_ft=daysfrac*weight if quelle!=1 
*/
* Drop variables that are nolonger needed
drop marginal age2 days schalt daysfrac 



log close


